@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: conversions.c 286 2004-10-30 12:22:09Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de> and
  *                     Rene Puls <rpuls@gmx.net>
@@ -31,9 +32,8 @@
 #include <unistd.h>
 #include <errno.h>
 #include <zlib.h>
-//#ifdef __STDC_ISO_10646__
 #include <libxml/HTMLparser.h>
-//#endif
+#include <langinfo.h>
 
 #include "conversions.h"
 #include "config.h"
@@ -44,9 +44,9 @@
 extern struct entity *first_entity;
 
 #ifdef STATIC_CONST_ICONV
-char * iconvert (const char * inbuf, char * from, char * to) {
+char * iconvert (const char * inbuf) {
 #else
-char * iconvert (char * inbuf, char * from, char * to) {
+char * iconvert (char * inbuf) {
 #endif
 	iconv_t cd;							/* Iconvs conversion descriptor. */
 	char *outbuf, *outbuf_first;		/* We need two pointers so we do not lose
@@ -54,14 +54,14 @@ char * iconvert (char * inbuf, char * from, char * to) {
 	size_t inbytesleft, outbytesleft;
 
 	/* Take a shortcut. */
-	if (strcasecmp (from, to) == 0)
+	if (strcasecmp (TARGET_CHARSET, "UTF-8") == 0)
 		return strdup(inbuf);
 	
 	inbytesleft = strlen(inbuf);
 	outbytesleft = strlen(inbuf);
 
-	/* iconv_open(nl_langinfo(CODESET), from); */
-	cd = iconv_open (to, from);
+	/* cd = iconv_open(nl_langinfo(CODESET), "UTF-8"); */
+	cd = iconv_open (TARGET_CHARSET, "UTF-8");
 	if (cd == (iconv_t) -1) {
 		return NULL;
 	}
@@ -398,129 +398,6 @@ char * WrapText (char * text, int width) {
 	return newtext;
 }
 
-/* Decompresses deflate compressed data. Probably unneeded,
- * see gzip_uncompress below.
- */
-void *zlib_uncompress(void *in_buf, int in_size, int *out_size, int voodoo_magic) {
-	char tmpstring[1024];
-	z_stream stream;
-	char *out_buf = NULL;
-	int out_buf_bytes = 0;
-	char tmp_buf[512];
-	int result;
-	int new_bytes;
-
-	/* Prepare the stream structure. */
-	stream.zalloc = NULL;
-	stream.zfree = NULL;
-	stream.opaque = NULL;
-	stream.next_in = in_buf;	
-	stream.avail_in = in_size;
-	stream.next_out = tmp_buf;
-	stream.avail_out = sizeof tmp_buf;
-	
-	if (out_size != NULL)
-		*out_size = 0;
-	
-	/* Deflated data from GZIP files can only be decompressed with voodoo magic(tm)! */
-	if (voodoo_magic)
-		inflateInit2(&stream, -MAX_WBITS);
-	else
-		inflateInit(&stream);
-	
-	do {
-		/* Should be Z_FINISH? */
-		result = inflate(&stream, Z_NO_FLUSH);
-		switch (result) {
-		case Z_ERRNO:
-		case Z_NEED_DICT:
-		case Z_BUF_ERROR:
-		case Z_MEM_ERROR:
-		case Z_DATA_ERROR:
-		case Z_VERSION_ERROR:
-			inflateEnd(&stream);
-			free(out_buf);
-			snprintf (tmpstring, sizeof(tmpstring), _("ERROR: zlib_uncompress: %d %s\n"), result, stream.msg);
-			UIStatus (tmpstring, 2, 1);
-			return NULL;
-		}
-		if (stream.avail_out < sizeof tmp_buf) {
-			/* Add the new uncompressed data to our output buffer. */
-			new_bytes = sizeof tmp_buf - stream.avail_out;
-			out_buf = realloc(out_buf, out_buf_bytes + new_bytes);
-			memcpy(out_buf + out_buf_bytes, tmp_buf, new_bytes);
-			out_buf_bytes += new_bytes;
-			stream.next_out = tmp_buf;
-			stream.avail_out = sizeof tmp_buf;
-		} else {
-			/* For some reason, inflate() didn't write out a single byte. */
-			inflateEnd(&stream);
-			free(out_buf);
-			UIStatus (_("ERROR: No output during decompression"), 2, 1);
-			return NULL;
-		}
-	} while (result != Z_STREAM_END);
-	
-	inflateEnd(&stream);
-	
-	/* Null-terminate the output buffer so it can be handled like a string. */
-	out_buf = realloc(out_buf, out_buf_bytes + 1);
-	out_buf[out_buf_bytes] = 0;
-	
-	/* The returned size does NOT include the additionall null byte! */
-	if (out_size != NULL)
-		*out_size = out_buf_bytes;
-	
-	return out_buf;
-}
-
-/* Decompressed gzip,deflate compressed data. This is what the webservers
- * usually send.
- */
-void *gzip_uncompress(void *in_buf, int in_size, int *out_size) {
-	char tmpstring[1024];
-	struct gzip_header *header;
-	char *data_start;
-	int offset = sizeof *header;
-	
-	header = in_buf;
-
-	if (out_size != NULL)
-		*out_size = 0;
-
-	if ((header->magic[0] != 0x1F) || (header->magic[1] != 0x8B)) {
-		UIStatus (_("ERROR: Invalid magic bytes for GZIP data"), 2, 1);
-		return NULL;
-	}
-	
-	if (header->method != 8) {
-		UIStatus (_("ERROR: Compression method is not deflate"), 2, 1);
-		return NULL;
-	}
-	
-	if (header->flags != 0 && header->flags != 8) {
-		snprintf (tmpstring, sizeof(tmpstring), _("ERROR: Unsupported flags %d"), header->flags);
-		UIStatus (tmpstring, 2, 1);
-		return NULL;
-	}
-	
-	if (header->flags & 8) {
-		/* skip the file name */
-		while (offset < in_size) {
-			if (((char *)in_buf)[offset] == 0) {
-				offset++;
-				break;
-			}
-			offset++;
-		}
-	}
-	
-	data_start = (char *)in_buf + offset;
-	
-	return zlib_uncompress(data_start, in_size - offset - 8, out_size, 1);
-}
-
-
 char *base64encode(char const *inbuf, unsigned int inbuf_size) {
 	static unsigned char const alphabet[64] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
@@ -637,3 +514,42 @@ void CleanupString (char * string, int tidyness) {
 		}
 	}
 }
+
+/* http://foo.bar/address.rdf -> http:__foo.bar_address.rdf */
+char * Hashify (const char * url) {
+	int i, len;
+	char *hashed_url;
+	
+	hashed_url = strdup(url);
+	
+	len = strlen(hashed_url);
+	
+	/* Don't allow filenames > 128 chars for teeny weeny
+	 * operating systems.
+	 */
+	if (len > 128) {
+		len = 128;
+		hashed_url[128] = '\0';
+	}
+	
+	for (i = 0; i < len; i++) {
+		if (((hashed_url[i] < 32) || (hashed_url[i] > 38)) &&
+			((hashed_url[i] < 43) || (hashed_url[i] > 46)) &&
+			((hashed_url[i] < 48) || (hashed_url[i] > 90)) &&
+			((hashed_url[i] < 97) || (hashed_url[i] > 122)) &&
+			(hashed_url[i] != 0))
+			hashed_url[i] = '_';
+		
+		/* Cygwin doesn't seem to like anything besides a-z0-9 in filenames.
+		   Zap'em! */
+#ifdef __CYGWIN__
+		if (((hashed_url[i] < 48) || (hashed_url[i] > 57)) &&
+			((hashed_url[i] < 65) || (hashed_url[i] > 90)) &&
+			((hashed_url[i] < 97) || (hashed_url[i] > 122)) &&
+			(hashed_url[i] != 0))
+			hashed_url[i] = '_';
+#endif
+	}
+	
+	return hashed_url;
+}
