@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: conversions.h 286 2004-10-30 12:22:09Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de> and
  *                     Rene Puls <rpuls@gmx.net>
@@ -24,30 +25,15 @@
 #define CONVERSIONS_H
 
 #ifdef STATIC_CONST_ICONV
-char * iconvert (const char * inbuf, char * from, char * to);
+char * iconvert (const char * inbuf);
 #else
-char * iconvert (char * inbuf, char * from, char * to);
+char * iconvert (char * inbuf);
 #endif
 char * UIDejunk (char * feed_description);
 char * WrapText (char * text, int width);
-void *zlib_uncompress(void *in_buf, int in_size, int *out_size, int voodoo_magic);
-void *gzip_uncompress(void *in_buf, int in_size, int *out_size);
 char *base64encode(char const *inbuf, unsigned int inbuf_size);
 char* decodechunked(char * chunked, unsigned int *inputlen);
 void CleanupString (char * string, int tidyness);
-
-struct gzip_header {
-	unsigned char magic[2];
-	unsigned char method;
-	unsigned char flags;
-	unsigned char mtime[4];
-	unsigned char xfl;
-	unsigned char os;
-};
-
-struct gzip_footer {
-	unsigned char crc32[4];
-	unsigned char size[4];
-};
+char * Hashify (const char * url);
 
 #endif
