@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: dialog.c 286 2004-10-30 12:22:09Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -229,12 +230,13 @@ int UIAddFeed (char * newurl) {
 	/* getnstr does not return newline... says the docs. */
 	new_ptr->feedurl = malloc (strlen(url)+1);
 	new_ptr->feed = NULL;
-	new_ptr->contentlength = 0;
+	new_ptr->content_length = 0;
 	new_ptr->title = NULL;
 	new_ptr->link = NULL;
 	new_ptr->description = NULL;
 	new_ptr->lastmodified = NULL;
 	new_ptr->lasthttpstatus = 0;
+	new_ptr->content_type = NULL;
 	new_ptr->netio_error = NET_ERR_OK;
 	new_ptr->connectresult = 0;
 	new_ptr->cookies = NULL;
@@ -275,7 +277,7 @@ int UIAddFeed (char * newurl) {
 			return -1;
 		else {
 			UIPerFeedFilter (new_ptr);
-			FilterPipe (new_ptr);
+			FilterPipeNG (new_ptr);
 			if ((DeXML (new_ptr)) != 0)
 				return -1;
 			else {
@@ -295,6 +297,7 @@ void FeedInfo (struct feed * current_feed) {
 	char *categories = NULL;
 	char *url;							/* feedurl - authinfo. */
 	char *tmp = NULL;
+	char *tmp2;
 	struct stat filetest;
 	
 	url = strdup (current_feed->feedurl);
@@ -302,15 +305,14 @@ void FeedInfo (struct feed * current_feed) {
 	/* Remove authinfo from URL. */
 	tmp = strstr (url, "@");
 	if (tmp != NULL) {
-		memmove (url+7, tmp+1, strlen(tmp));
+		tmp2 = strstr (url, "://");
+		tmp2 += 3;
+		memmove (tmp2, tmp+1, strlen(tmp));
 	}
 	
 	centerx = COLS / 2;
 	
-	hashme = malloc (strlen(current_feed->feedurl)+1);
-	strncpy (hashme, current_feed->feedurl, strlen(current_feed->feedurl)+1);
-	Hashify (hashme);
-	
+	hashme = Hashify(current_feed->feedurl);
 	len = (strlen(getenv("HOME")) + strlen(hashme) + 18);
 	file = malloc (len);
 	snprintf (file, len, "%s/.snownews/cache/%s", getenv("HOME"), hashme);
@@ -350,9 +352,15 @@ void FeedInfo (struct feed * current_feed) {
 	   so you don't have to know what the HTTP return codes mean.
 	   Yes I think I got the idea from cdparanoia. :) */
 	if (current_feed->lasthttpstatus != 0) {
-		len = strlen(_("Last webserver status: %d"));
-		mvprintw (12, centerx-(COLS/2-7), _("Last webserver status: %d"), current_feed->lasthttpstatus);
-		
+		if (current_feed->content_type == NULL) {
+			len = strlen(_("Last webserver status: %d"));
+			mvprintw (12, centerx-(COLS/2-7), _("Last webserver status: %d"), current_feed->lasthttpstatus);
+		} else {
+			len = strlen(_("Last webserver status: (%s) %d")) + strlen(current_feed->content_type) - 2; /* -2 == %s */
+			mvprintw (12, centerx-(COLS/2-7), _("Last webserver status: (%s) %d"),
+				current_feed->content_type, current_feed->lasthttpstatus);
+		}
+	
 		switch (current_feed->lasthttpstatus) {
 			case 200:
 			case 304:
@@ -379,7 +387,7 @@ void FeedInfo (struct feed * current_feed) {
 		UISupportDrawBox (5, 13, COLS-6, 14);
 		attron (WA_REVERSE);
 		mvaddstr (13, 7, _("Filtered through:"));
-		mvaddnstr (13, 7+strlen(_("Filtered through:"))+1, current_feed->perfeedfilter, COLS-14);
+		mvaddnstr (13, 7+strlen(_("Filtered through:"))+1, current_feed->perfeedfilter, COLS-14-strlen(_("Filtered through:")));
 	}
 	
 	UIStatus (_("Displaying feed information."), 0, 0);
