@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: interface.c 286 2004-10-30 12:22:09Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -112,7 +113,7 @@ void UIDisplayItem (struct newsitem * current_item, struct feed * current_feed,
 			   and corrupt mem while resizing the window. */
 			
 			newtext = UIDejunk (current_feed->description);	
-			converted = iconvert (newtext, "UTF-8", TARGET_CHARSET);
+			converted = iconvert (newtext);
 			if (converted == NULL)
 				converted = strdup (newtext);
 			
@@ -126,7 +127,7 @@ void UIDisplayItem (struct newsitem * current_item, struct feed * current_feed,
 			/* Print original feed's description and not "(New headlines)". */
 			if (current_feed->smartfeed == 1) {
 				newtext = UIDejunk (current_item->data->parent->description);
-				converted = iconvert (newtext, "UTF-8", TARGET_CHARSET);
+				converted = iconvert (newtext);
 				if (converted == NULL)
 				converted = strdup (newtext);
 			
@@ -148,7 +149,7 @@ void UIDisplayItem (struct newsitem * current_item, struct feed * current_feed,
 		/* And don't crash if title is empty. */
 		if (current_item->data->title != NULL) {
 			newtext = UIDejunk (current_item->data->title);		
-			converted = iconvert (newtext, "UTF-8", TARGET_CHARSET);
+			converted = iconvert (newtext);
 			if (converted == NULL)
 				converted = strdup (newtext);
 			
@@ -173,7 +174,7 @@ void UIDisplayItem (struct newsitem * current_item, struct feed * current_feed,
 				/* Only generate a new scroll list if we need to rewrap everything.
 				   Otherwise just skip this block. */
 				if (rewrap) {
-					converted = iconvert (current_item->data->description, "UTF-8", TARGET_CHARSET);
+					converted = iconvert (current_item->data->description);
 					if (converted == NULL)
 						converted = strdup (current_item->data->description);					
 					newtext = UIDejunk (converted);
@@ -507,7 +508,7 @@ int UIDisplayFeed (struct feed * current_feed) {
 			columns = COLS-10;
 			
 			newtext = UIDejunk (current_feed->description);
-			converted = iconvert (newtext, "UTF-8", TARGET_CHARSET);
+			converted = iconvert (newtext);
 			if (converted == NULL)
 				converted = strdup (newtext);
 						
@@ -565,7 +566,7 @@ int UIDisplayFeed (struct feed * current_feed) {
 				} else
 					newtext = UIDejunk (curitem_ptr->data->title);
 				
-				converted = iconvert (newtext, "UTF-8", TARGET_CHARSET);
+				converted = iconvert (newtext);
 				if (converted == NULL)
 					converted = strdup (newtext);
 				
@@ -1255,11 +1256,7 @@ void UIMainInterface (void) {
 					cur_ptr = highlighted;
 					
 					/* Remove cachefile from filesystem. */
-				
-					hashme = malloc (strlen(highlighted->feedurl)+1);
-					strncpy (hashme, highlighted->feedurl, strlen(highlighted->feedurl)+1);
-					Hashify (hashme);
-		
+					hashme = Hashify(highlighted->feedurl);
 					len = (strlen(getenv("HOME")) + strlen(hashme) + 18);
 					file = malloc (len);
 					snprintf (file, len, "%s/.snownews/cache/%s", getenv("HOME"), hashme);
