@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: io-internal.c 286 2004-10-30 12:22:09Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -38,6 +39,7 @@
 #include "config.h"
 
 #include "main.h"
+#include "conversions.h"
 #include "filters.h"
 #include "categories.h"
 #include "netio.h"
@@ -197,7 +199,7 @@ int UpdateFeed (struct feed * cur_ptr) {
 	
 	/* Feed downloaded content through the defined filter. */
 	if (cur_ptr->perfeedfilter != NULL)
-		FilterPipe (cur_ptr);
+		FilterPipeNG (cur_ptr);
 	
 	/* If there is no feed, return. */
 	if (cur_ptr->feed == NULL)
@@ -234,7 +236,7 @@ int LoadFeed (struct feed * cur_ptr) {
 	int retval;
 	char filebuf[4096];			/* File I/O block buffer. */
 	char file[512];
- 	char hashme[512];			/* Hashed filename. */
+ 	char *hashme;				/* Hashed filename. */
  	char tmp[1024];
 	FILE *cache;
 	
@@ -242,9 +244,9 @@ int LoadFeed (struct feed * cur_ptr) {
 	if (cur_ptr->smartfeed == 1)
 		return 0;
 	
-	strncpy (hashme, cur_ptr->feedurl, sizeof(hashme));
-	Hashify (hashme);
+	hashme = Hashify(cur_ptr->feedurl);
 	snprintf (file, sizeof(file), "%s/.snownews/cache/%s", getenv("HOME"), hashme);
+	free (hashme);
 	cache = fopen (file, "r");
 	
 	if (cache == NULL) {
@@ -269,7 +271,7 @@ int LoadFeed (struct feed * cur_ptr) {
 			break;
 	}
 	
-	cur_ptr->contentlength = len;
+	cur_ptr->content_length = len;
 	
 	if (cur_ptr->feed == NULL)
 		return 1;
@@ -332,7 +334,7 @@ int LoadAllFeeds (int numfeeds) {
  */
 void WriteCache (void) {
 	char file[512];				/* File locations. */
-	char hashme[512];			/* Cache file name. */
+	char *hashme;				/* Cache file name. */
 	char readstatus[2];
 	char syscall[512];
 	FILE *configfile;
@@ -421,9 +423,9 @@ void WriteCache (void) {
 		/* 
 		 * Write cache.
 		 */
-		strncpy (hashme, cur_ptr->feedurl, sizeof(hashme));
-		Hashify (hashme);
+		hashme = Hashify(cur_ptr->feedurl);
 		snprintf (file, sizeof(file), "%s/.snownews/cache/%s", getenv("HOME"), hashme);
+		free (hashme);
 		cache = fopen (file, "w+");
 
 		if (cache == NULL)
