@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: main.c 286 2004-10-30 12:22:09Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -34,6 +35,7 @@
 #include <sys/stat.h>
 #include <time.h>
 #include <signal.h>
+#include <sys/wait.h>
 
 #include "config.h"
 #include "interface.h"
@@ -86,26 +88,19 @@ void MainSignalHandler (int sig) {
 	}
 }
 
-/* http://foo.bar/address.rdf -> http:__foo.bar_address.rdf */
-void Hashify (char * url) {
-	int i;
-	for (i = 0; i <= strlen(url); i++) {
-		if (url[i] == '/') {
-			url[i] = '_';
-		}
-		/* Cygwin doesn't seem to like anything besides a-z0-9 in filenames.
-		   Zap'em! */
-#ifdef __CYGWIN__
-		if (((i < 48) && (i > 57)) ||
-			((i < 65) && (i > 90)) ||
-			((i < 97) && (i > 122)) ||
-			(i != 0)) {
-			url[i] = '_';
-		}
-#endif
-	}
+/* Automatic child reaper. */
+void sigChildHandler (int sig) {
+	int status, child_val;
+
+	/* Wait for any child without blocking */
+	if (waitpid(-1, &status, WNOHANG) < 0)
+			return;
+
+	if (WIFEXITED(status))
+		child_val = WEXITSTATUS(status);
 }
 
+
 int main (int argc, char *argv[]) {
 	int autoupdate = 0;		/* Automatically update feeds on app start... or not if set to 0. */
 	int numfeeds;			/* Number of feeds loaded from Config(). */
@@ -146,6 +141,12 @@ int main (int argc, char *argv[]) {
 	/* Install SIGINT signal handler. */
 	signal (SIGINT, MainSignalHandler);
 	
+	/* Un-broken pipify */
+	signal (SIGPIPE, SIG_IGN);
+	
+	/* Call the reaper */
+	signal (SIGCHLD, sigChildHandler);
+	
 	InitCurses();
 	
 	/* Check if configfiles exist and create/read them. */
