@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: net-support.h 286 2004-10-30 12:22:09Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -24,5 +25,7 @@
 #define NET_SUPPORT_H
 
 int NetSupportAuth (struct feed * cur_ptr, char * authdata, char * url, char * netbuf);
+int checkValidHTTPHeader (const unsigned char * header, int size);
+int checkValidHTTPURL (const unsigned char * url);
 
 #endif
