@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: netio.c 286 2004-10-30 12:22:09Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -39,7 +40,7 @@
 #include <string.h>
 #include <errno.h>
 #include <unistd.h>
-#include <fcntl.h>
+//#include <fcntl.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -57,6 +58,7 @@
 #include "ui-support.h"
 #include "net-support.h"
 #include "io-internal.h"
+#include "zlib_interface.h"
 
 static int const MAX_HTTP_REDIRECTS = 10;	/* Maximum number of redirects we will follow. */
 static int const NET_TIMEOUT = 20;			/* Global network timeout in sec */
@@ -160,9 +162,6 @@ int NetConnect (int * my_socket, char * host, struct feed * cur_ptr, int httppro
 		return -1;
 	}
 	
-	/* Set socket to nonblock mode to make it possible to interrupt the connect. */
-	fcntl(*my_socket, F_SETFL, fcntl(*my_socket, F_GETFL, 0) | O_NONBLOCK);
-	
 	/* If proxyport is 0 we didn't execute the if http_proxy statement in main
 	   so there is no proxy. On any other value of proxyport do proxyrequests instead. */
 	if (proxyport == 0) {
@@ -257,9 +256,6 @@ int NetConnect (int * my_socket, char * host, struct feed * cur_ptr, int httppro
 		}
 	}
 	
-	/* Set socket back to blocking mode. */
-	fcntl(*my_socket, F_SETFL, fcntl(*my_socket, F_GETFL, 0) & ~O_NONBLOCK);
-	
 	free (realhost);
 	return 0;
 }
@@ -320,7 +316,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 	
 	/* Reconstruct digest authinfo for every request so we don't reuse
 	   the same nonce value for more than one request.
-	   This happens on superflous time on 303 redirects. */
+	   This happens one superflous time on 303 redirects. */
 	if ((cur_ptr->authinfo != NULL) && (cur_ptr->servauth != NULL)) {
 		if (strstr (cur_ptr->authinfo, " Digest ") != NULL) {
 			NetSupportAuth(cur_ptr, authdata, url, cur_ptr->servauth);
@@ -394,6 +390,12 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 		fclose (stream);
 		return NULL;
 	}
+	if (checkValidHTTPHeader(servreply, sizeof(servreply)) != 0) {
+		cur_ptr->netio_error = NET_ERR_HTTP_PROTO_ERR;
+		fclose (stream);
+		return NULL;
+	}
+	
 	tmpstatus = strdup(servreply);
 	savestart = tmpstatus;
 
@@ -457,6 +459,13 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 						fclose (stream);
 						return NULL;
 					}
+					
+					if (checkValidHTTPHeader(netbuf, sizeof(netbuf)) != 0) {
+						cur_ptr->netio_error = NET_ERR_HTTP_PROTO_ERR;
+						fclose (stream);
+						return NULL;
+					}
+	
 					/* Split netbuf into hostname and trailing url.
 					   Place hostname in *newhost and tail into *newurl.
 					   Close old connection and reconnect to server.
@@ -473,6 +482,14 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 						   after the word "Location:" */
 						strsep (&redirecttarget, " ");
 						
+						if (redirecttarget == NULL) {
+							cur_ptr->problem = 1;
+							cur_ptr->netio_error = NET_ERR_REDIRECT_ERR;
+							free (freeme);
+							fclose (stream);
+							return NULL;
+						}
+						
 						/* Location must start with "http", otherwise switch on quirksmode. */
 						if (strncmp(redirecttarget, "http", 4) != 0)
 							quirksmode = 1;
@@ -499,9 +516,17 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 						
 						/* Change cur_ptr->feedurl on 301. */
 						if (cur_ptr->lasthttpstatus == 301) {
-							if (!suppressoutput)
+							/* Check for valid redirection URL */
+							if (checkValidHTTPURL(newlocation) != 0) {
+								cur_ptr->problem = 1;
+								cur_ptr->netio_error = NET_ERR_REDIRECT_ERR;
+								fclose (stream);
+								return NULL;
+							}
+							if (!suppressoutput) {
 								UIStatus (_("URL points to permanent redirect, updating with new location..."), 2, 0);
-							printlog (cur_ptr, _("URL points to permanent redirect, updating with new location..."));
+								printlog (cur_ptr, _("URL points to permanent redirect, updating with new location..."));
+							}
 							free (cur_ptr->feedurl);
 							if (authdata == NULL)
 								cur_ptr->feedurl = strdup (newlocation);
@@ -614,38 +639,63 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 			return NULL;
 		}
 
-		/* Max line length of sizeof(netbuf) is assumed here.
-		   If header has longer lines than 4096 bytes something may go wrong. :) */
 		if ((fgets (netbuf, sizeof(netbuf), stream)) == NULL)
 			break;
 		
+		if (checkValidHTTPHeader(netbuf, sizeof(netbuf)) != 0) {
+			cur_ptr->netio_error = NET_ERR_HTTP_PROTO_ERR;
+			fclose (stream);
+			return NULL;
+		}
+		
 		if (strncasecmp (netbuf, "Transfer-Encoding", 17) == 0) {
 			/* Chunked transfer encoding. HTTP/1.1 extension.
 			   http://www.w3.org/Protocols/rfc2616/rfc2616-sec3.html#sec3.6.1 */
-			chunked = 1;
+			if (strstr (netbuf, "chunked") != NULL)
+				chunked = 1;
 		}
 		/* Get last modified date. This is only relevant on HTTP 200. */
 		if ((strncasecmp (netbuf, "Last-Modified", 13) == 0) &&
 			(cur_ptr->lasthttpstatus == 200)) {
 			tmpstring = strdup(netbuf);
 			freeme = tmpstring;
-			strsep (&tmpstring, ":");
-			tmpstring++;
-			free(cur_ptr->lastmodified);
-			cur_ptr->lastmodified = malloc (strlen(tmpstring)+1);
-			strncpy (cur_ptr->lastmodified, tmpstring, strlen(tmpstring)+1);
-			if (cur_ptr->lastmodified[strlen(cur_ptr->lastmodified)-1] == '\n')
-				cur_ptr->lastmodified[strlen(cur_ptr->lastmodified)-1] = '\0';
-			if (cur_ptr->lastmodified[strlen(cur_ptr->lastmodified)-1] == '\r')
-				cur_ptr->lastmodified[strlen(cur_ptr->lastmodified)-1] = '\0';
-			free(freeme);
+			strsep (&tmpstring, " ");
+			if (tmpstring == NULL)
+				free (freeme);
+			else {
+				free(cur_ptr->lastmodified);
+				cur_ptr->lastmodified = strdup(tmpstring);
+				if (cur_ptr->lastmodified[strlen(cur_ptr->lastmodified)-1] == '\n')
+					cur_ptr->lastmodified[strlen(cur_ptr->lastmodified)-1] = '\0';
+				if (cur_ptr->lastmodified[strlen(cur_ptr->lastmodified)-1] == '\r')
+					cur_ptr->lastmodified[strlen(cur_ptr->lastmodified)-1] = '\0';
+				free(freeme);
+			}
 		}
-		/* Check and parse Content-Encoding header. */
 		if (strncasecmp (netbuf, "Content-Encoding", 16) == 0) {
-			/* Will also catch x-gzip. */
 			if (strstr (netbuf, "gzip") != NULL)
 				inflate = 1;
-		}		
+		}
+		if (strncasecmp (netbuf, "Content-Type", 12) == 0) {
+			tmpstring = strdup(netbuf);
+			freeme = tmpstring;
+			strsep(&tmpstring, " ");
+			if (tmpstring == NULL)
+				free (freeme);
+			else {
+				freeme2 = NULL;
+				freeme2 = strstr(tmpstring, ";");
+				if (freeme2 != NULL)
+					freeme2[0] = '\0';
+				free(cur_ptr->content_type);
+				cur_ptr->content_type = strdup(tmpstring);
+				if (cur_ptr->content_type[strlen(cur_ptr->content_type)-1] == '\n')
+					cur_ptr->content_type[strlen(cur_ptr->content_type)-1] = '\0';
+				if (cur_ptr->content_type[strlen(cur_ptr->content_type)-1] == '\r')
+					cur_ptr->content_type[strlen(cur_ptr->content_type)-1] = '\0';
+				free(freeme);
+			}
+		}
 		/* HTTP authentication
 		 *
 		 * RFC 2617 */
@@ -757,7 +807,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 	body = realloc(body, length+1);
 	body[length] = '\0';
 	
-	cur_ptr->contentlength = length;
+	cur_ptr->content_length = length;
 	
 	/* Close connection. */
 	fclose (stream);
@@ -773,11 +823,16 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed * cur_ptr, c
 	/* If inflate==1 we need to decompress the content.. */
 	if (inflate == 1) {
 		/* gzipinflate */
-		inflatedbody = gzip_uncompress (body, length, &cur_ptr->contentlength);
+		/*inflatedbody = gzip_uncompress (body, length, &cur_ptr->content_length);
 		if (inflatedbody == NULL) {
 			free (body);
 			cur_ptr->netio_error = NET_ERR_GZIP_ERR;
 			return NULL;
+		}*/
+		if (jg_gzip_uncompress (body, length, (void **)&inflatedbody, &cur_ptr->content_length) != 0) {
+			free (body);
+			cur_ptr->netio_error = NET_ERR_GZIP_ERR;
+			return NULL;
 		}
 		
 		/* Copy uncompressed data back to body. */
@@ -802,6 +857,11 @@ char * DownloadFeed (char * url, struct feed * cur_ptr, int suppressoutput) {
 	char *tmpstr;
 	int httpproto = 0;			/* 0: http; 1: https */
 	
+	if (checkValidHTTPURL(url) != 0) {
+		cur_ptr->problem = 1;
+		cur_ptr->netio_error = NET_ERR_HTTP_PROTO_ERR;
+		return NULL;
+	}
 	/* strstr will match _any_ substring. Not good, use strncasecmp with length 5! */
 	if (strncasecmp (url, "https", 5) == 0)
 		httpproto = 1;
@@ -847,9 +907,7 @@ char * DownloadFeed (char * url, struct feed * cur_ptr, int suppressoutput) {
 		cur_ptr->problem = 1;
 		return NULL;
 	}
-		
 	returndata = NetIO (&my_socket, host, url, cur_ptr, authdata, httpproto, suppressoutput);
-	
 	if ((returndata == NULL) && (cur_ptr->netio_error != NET_ERR_OK)) {
 		cur_ptr->problem = 1;
 	}
