@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: setup.c 92 2004-10-06 10:29:54Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -612,12 +613,13 @@ int Config (void) {
 			new_ptr = malloc (sizeof(struct feed));
 			
 			new_ptr->feed = NULL;
-			new_ptr->contentlength = 0;
+			new_ptr->content_length = 0;
 			new_ptr->title = NULL;
 			new_ptr->link = NULL;
 			new_ptr->description = NULL;
 			new_ptr->lastmodified = NULL;
 			new_ptr->lasthttpstatus = 0;
+			new_ptr->content_type = NULL;
 			new_ptr->netio_error = NET_ERR_OK;
 			new_ptr->connectresult = 0;
 			new_ptr->cookies = NULL;
