@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: ui-support.c 92 2004-10-06 10:29:54Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -86,12 +87,13 @@ void SwapPointers (struct feed * one, struct feed * two) {
 	
 	tmp->feedurl = one->feedurl;
 	tmp->feed = one->feed;
-	tmp->contentlength = one->contentlength;
+	tmp->content_length = one->content_length;
 	tmp->title = one->title;
 	tmp->link = one->link;
 	tmp->description = one->description;
 	tmp->lastmodified = one->lastmodified;
 	tmp->lasthttpstatus = one->lasthttpstatus;
+	tmp->content_type = one->content_type;
 	tmp->cookies = one->cookies;
 	tmp->authinfo = one->authinfo;
 	tmp->servauth = one->servauth;
@@ -106,12 +108,13 @@ void SwapPointers (struct feed * one, struct feed * two) {
 		
 	one->feedurl = two->feedurl;
 	one->feed = two->feed;
-	one->contentlength = two->contentlength;
+	one->content_length = two->content_length;
 	one->title = two->title;
 	one->link = two->link;
 	one->description = two->description;
 	one->lastmodified = two->lastmodified;
 	one->lasthttpstatus = two->lasthttpstatus;
+	one->content_type = two->content_type;
 	one->cookies = two->cookies;
 	one->authinfo = two->authinfo;
 	one->servauth = two->servauth;
@@ -126,12 +129,13 @@ void SwapPointers (struct feed * one, struct feed * two) {
 	
 	two->feedurl = tmp->feedurl;
 	two->feed = tmp->feed;
-	two->contentlength = tmp->contentlength;
+	two->content_length = tmp->content_length;
 	two->title = tmp->title;
 	two->link = tmp->link;
 	two->description = tmp->description;
 	two->lastmodified = tmp->lastmodified;
 	two->lasthttpstatus = tmp->lasthttpstatus;
+	two->content_type = tmp->content_type;
 	two->cookies = tmp->cookies;
 	two->authinfo = tmp->authinfo;
 	two->servauth = tmp->servauth;
