@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: updatecheck.c 194 2004-10-21 16:09:08Z kiza $
  * 
  * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
  * http://kiza.kcore.de/software/snownews/
@@ -56,6 +57,7 @@ void AutoVersionCheck (void) {
 	update->cookies = NULL;
 	update->authinfo = NULL;
 	update->title = NULL;
+	update->content_type = NULL;
 	
 	/* We check once a week. */
 	snprintf (timestring, sizeof(timestring), "%d", (int) time(NULL));
@@ -83,7 +85,8 @@ void AutoVersionCheck (void) {
 		}
 	}
 	
-	url = strdup ("http://home.kcore.de/~kiza/software/snownews/version");
+	url = strdup ("http://kiza.kcore.de/software/snownews/version");
+	update->feedurl = strdup(url);
 	freeme = url;
 	versionstring = DownloadFeed (url, update, 1);
 	free (url);
@@ -99,11 +102,11 @@ void AutoVersionCheck (void) {
 			printf ("http://snownews.kcore.de/download/snownews-%s.tar.gz (.sign)\n", versionstring);
 			printf ("http://snownews.kcore.de/download/snownews-%s.i386.tar.bz2 (.sign)\n", versionstring);
 		}
-	free (versionstring);
-	
-	if (update->lastmodified != NULL)
-		free (update->lastmodified);
 	}
+	free (versionstring);
+	free (update->lastmodified);
+	free (update->feedurl);
+	free (update->content_type);
 	
 	free (update);
 	
