@@ -1,4 +1,5 @@
 /* Snownews - A lightweight console RSS newsreader
+ * $Id: xmlparse.c 181 2004-10-20 14:10:45Z kiza $
  * 
  * Copyright 2003-2004 Rene Puls <rpuls@gmx.net> and
  *                     Oliver Feiler <kiza@kcore.de>
@@ -269,7 +270,10 @@ int DeXML (struct feed * cur_ptr) {
 	xmlDocPtr doc;
 	xmlNodePtr cur;
 	struct newsitem *cur_item;
-		
+	
+	if (cur_ptr->feed == NULL)
+		return -1;
+	
 	saverestore = 0;
 	/* Wenn cur_ptr->items != NULL dann knnen wir uns item->readstatus
 	   zwischenspeichern. */
